@@ -3,12 +3,13 @@
 #include <libintl.h>
 #include <QApplication>
 #include <qtextstream.h>
+#include <QTextCodec>
 #include <QTranslator>
 #include "mainwindow.h"
 #include <QDir>
 #include <fcitx-utils/utils.h>
 
-#define FCITXSKIN_PATH "/usr/share/fcitx-qimpanel/skin/ "
+#define FCITXSKIN_PATH (PREFIX "/share/fcitx-qimpanel/skin/")
 #define BUFF_SIZE (512)
 char sharePath[BUFF_SIZE] = {0};
 
@@ -18,7 +19,7 @@ int main(int argc, char *argv[])
     QTranslator translator;
     QString locale = QLocale::system().name();
     if(locale == "zh_CN") {
-       if (translator.load("/usr/share/fcitx-qimpanel/fcitx_skin_zh_CN.qm") == false)
+       if (translator.load(PREFIX "/share/fcitx-qimpanel/fcitx_skin_zh_CN.qm") == false)
 //        if (translator.load(QString(getQimpanelSharePath("fcitx_skin_zh_CN.qm"))) == false)
             qDebug() << "load qm error.";
     }
@@ -26,7 +27,15 @@ int main(int argc, char *argv[])
     QApplication app(argc, argv);
 //    app.installTranslator(&translator);
     app.setApplicationName("fcitx-qimpanel-configtool");
+    #ifdef IS_QT_5
 
+    #endif
+    #ifdef IS_QT_4
+        QTextCodec::setCodecForTr(QTextCodec::codecForLocale());
+        QTextCodec::setCodecForCStrings(QTextCodec::codecForLocale());
+        QTextCodec::setCodecForTr(QTextCodec::codecForName("UTF-8"));
+        QTextCodec::setCodecForCStrings(QTextCodec::codecForName("UTF-8"));
+    #endif
     QString localPath = qgetenv("HOME") + "/.config/";
     QDir *temp = new QDir;
     if(false == temp->exists(localPath + "fcitx-qimpanel"))
@@ -43,7 +52,7 @@ int main(int argc, char *argv[])
     }
 
     setlocale(LC_ALL,"");
-    bindtextdomain ("fcitx-qimpanel", "/usr/share/locale"); //告诉gettext最终的生成的翻译文件mo的位置
+    bindtextdomain ("fcitx-qimpanel", PREFIX "/share/locale"); //告诉gettext最终的生成的翻译文件mo的位置
     bind_textdomain_codeset("fcitx-qimpanel","UTF-8"); //指定域消息条目(mo)中消息的字符编码
     textdomain("fcitx-qimpanel");//设定翻译环境，即指定使用gettext的翻译。
 
