@@ -1,14 +1,14 @@
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
+#include "config.h"
 
 #include <QDebug>
 #include <QDir>
 #include <QMessageBox>
-#include <QQmlContext>
 #include <QTime>
 #include <libintl.h>
 
-#define FCITXSKINSYSTEM_PATH "/usr/share/fcitx-qimpanel/skin/"
+#define FCITXSKINSYSTEM_PATH (PREFIX "/share/fcitx-qimpanel/skin/")
 
 MainWindow::MainWindow(QWidget *parent) :
     QDialog(parent),
@@ -16,7 +16,12 @@ MainWindow::MainWindow(QWidget *parent) :
 {
     ui->setupUi(this);
     qmlRegisterType<CandidateWord>();//注册CandidateWord列表到qml
-    qmlView = new QQuickWidget;
+    #ifdef IS_QT_5
+        qmlView = new QQuickWidget;
+    #endif
+    #ifdef IS_QT_4
+         qmlView = new QDeclarativeView;
+    #endif
     listWidgetChangeClearFlag = false;
     mSkinFcitx = new SkinFcitx;
     mMainModer = MainModel::self();
@@ -38,7 +43,7 @@ MainWindow::MainWindow(QWidget *parent) :
     ui->radioButtonHorizontal->setText(gettext("Horizontal"));
     ui->radioButtonVertical->setText(gettext("Vertical"));
 
-    ui->labelAllSkin->setText(gettext("All Skin"));
+    ui->labelAllSkin->setText(gettext("All Skins"));
     ui->labelPreview->setText(gettext("Preview"));
     ui->labelDescription->setText(gettext("Description: Click to select and preview, double-click local to edit, save locally."));
     ui->pushButtonApply->setText(gettext("&Apply"));
@@ -107,7 +112,7 @@ void MainWindow::sltOnAllSkinItemDoubleClicked(QListWidgetItem *item)
 {
     if(curtSkinType.indexOf("local")==-1)
     {
-        QString localPath= "/usr/share/fcitx-qimpanel/skin/"+ curtSkinType.mid(0,curtSkinType.indexOf("(local)"));
+        QString localPath = PREFIX "/share/fcitx-qimpanel/skin/"+ curtSkinType.mid(0,curtSkinType.indexOf("(local)"));
         qDebug()<<localPath;
         QDir *temp = new QDir;
         if(true == temp->exists(localPath + "/skin.ini"))
@@ -143,7 +148,7 @@ void MainWindow::on_listWidgetAllSkin_currentItemChanged(QListWidgetItem *curren
     curtSkinType = current->text();
     if(curtSkinType.indexOf("local")==-1)
     {
-        QString localPath= "/usr/share/fcitx-qimpanel/skin/"+ curtSkinType.mid(0,curtSkinType.indexOf("(local)"));
+        QString localPath = PREFIX "/share/fcitx-qimpanel/skin/"+ curtSkinType.mid(0,curtSkinType.indexOf("(local)"));
         qDebug()<<localPath;
         QDir *temp = new QDir;
         if(true == temp->exists(localPath + "/skin.ini"))
@@ -310,11 +315,19 @@ void MainWindow::setSkinBase()
     if (mSkinFcitx != skin)
        delete mSkinFcitx;
     mSkinFcitx = skin;
-    qmlView->rootContext()->setContextProperty("mainSkin", mSkinFcitx);//把qt程序暴露到qml
-    qmlView->rootContext()->setContextProperty("mainModel", mMainModer);
-    qmlView->setSource(QUrl("qrc:/new/prefix1/main.qml"));
+#ifdef IS_QT_5
     qmlView->setAttribute(Qt::WA_AlwaysStackOnTop);
     qmlView->setClearColor(Qt::transparent);
+    qmlView->rootContext()->setContextProperty("mainSkin", mSkinFcitx);//把qt程序暴露到qml
+    qmlView->rootContext()->setContextProperty("mainModel", mMainModer);
+    qmlView->setSource(QUrl("qrc:/new/prefix1/qt5_main.qml"));
+#endif
+#ifdef IS_QT_4
+    qmlView->rootContext()->setContextProperty("mainSkin", mSkinFcitx);//把qt程序暴露到qml
+    qmlView->rootContext()->setContextProperty("mainModel", mMainModer);
+    qmlView->setSource(QUrl("qrc:/new/prefix1/qt4_main.qml"));
+#endif
+
     mLayout->addWidget(qmlView);
     mMainModer->emitSigMainWindowSizeChanged();
 }
@@ -328,14 +341,6 @@ void MainWindow::sltOnPushButtonApply()
     if((qAbs(currentTime-timeFlag) > 1)||(flag == 0))
     {
         flag ++;
-//        qDebug()<<"MainWindow::sltOnPushButtonApply()->killall -HUP";
-//        QString cmd2 = "killall -HUP fcitx-qimpanel";
-//        QByteArray ba2 = cmd2.toLatin1();
-//        const char * transpd2 = ba2.data();
-//        if(0!= system(transpd2))
-//        {
-//            return ;
-//        }
         qDebug()<<"emit sigRestartQimpanel();";
         emit sigRestartQimpanel();
     }
