@@ -25,38 +25,57 @@
 #include <QMessageBox>
 #include <QSettings>
 #include <libintl.h>
-
+#include <QProcess>
 #include <fcitx-config/fcitx-config.h>
+#include <stdio.h>
 
 #include "main.h"
 #include "my_action.h"
 #include "main_controller.h"
 #include "system_tray_menu.h"
-#include "config.h"
 #include "skin/skinfcitx.h"
 
 SystemTrayMenu::SystemTrayMenu(PanelAgent *agent)
     : QMenu()
 {
     mAgent = agent;
+    configtoolPro= new QProcess;
 }
 
 SystemTrayMenu::~SystemTrayMenu()
 {
-
+    if(configtoolPro)
+        free(configtoolPro);
+    delete mVKListMenu;
+    delete mSkinMenu;
+    delete mMozcHiraganaMenu;
+    delete mMozcToolMenu;
 }
 
 void SystemTrayMenu::init()
 {
-
-    updateMainMenu();
+    mVKListMenu = new QMenu(gettext("Virtual Keyboard"), this);
+    mSkinMenu = new QMenu(gettext("Skin"), this);
+    mMozcHiraganaMenu = new QMenu(gettext("Mozc Edit mode"), this);
+    mMozcToolMenu = new QMenu(gettext("Mozc Tool"), this);
+    QObject::connect(this, SIGNAL(aboutToHide()), this,
+        SLOT(clearMenu()));
 
     QObject::connect(this, SIGNAL(aboutToShow()), this,
         SLOT(triggerUpdateVKListMenu()));
 
+    QObject::connect(this, SIGNAL(aboutToShow()), this,
+        SLOT(truggerUpdateMozcHiraganaMenu()));
+
+    QObject::connect(this, SIGNAL(aboutToShow()), this,
+        SLOT(truggerUpdateMozcToolMenu()));
+
     QObject::connect(this, SIGNAL(aboutToShow()), this,
         SLOT(triggerUpdateIMListMenu()));
 
+    QObject::connect(this, SIGNAL(aboutToShow()), this,
+        SLOT(updateMainMenu()));
+
     QObject::connect(this, SIGNAL(triggered(QAction*)), this,
         SLOT(menuItemOnClick(QAction *)));
 
@@ -68,7 +87,12 @@ void SystemTrayMenu::init()
 
     QObject::connect(mAgent, SIGNAL(updateProperty(KimpanelProperty)), this,
         SLOT(updateProperty(KimpanelProperty)));
-
+    triggerUpdateVKListMenu();
+    truggerUpdateMozcHiraganaMenu();
+    truggerUpdateMozcToolMenu();
+    triggerUpdateIMListMenu();
+    triggerUpdateIMListMenu();
+    updateMainMenu();
 }
 
 void SystemTrayMenu::registerProperties(const QList<KimpanelProperty> &props)
@@ -76,8 +100,8 @@ void SystemTrayMenu::registerProperties(const QList<KimpanelProperty> &props)
     int count = 0;
     mStatusMenuList.clear();
     foreach(const KimpanelProperty &prop, props) {
-        //qDebug() << QString("registerProperties(1:%1 2:%2 3:%3 4:%4 5:%5 6:%6)").arg(prop.key)
-        //    .arg(prop.label).arg(prop.icon).arg(prop.tip).arg(prop.state).arg(prop.menu);
+//        qDebug() << i<<QString("registerProperties(1:%1 2:%2 3:%3 4:%4 5:%5 6:%6)\n").arg(prop.key)
+//            .arg(prop.label).arg(prop.icon).arg(prop.tip).arg(prop.state).arg(prop.menu);
         if (count ++ < StatusMenuSkip)
             continue;
         if (prop.key == "/Fcitx/vk")
@@ -90,34 +114,47 @@ void SystemTrayMenu::updateProperty(const KimpanelProperty &prop)
 {
     if (gettext("No input window") == prop.label)
         return;
-
     this->mCurtIMLabel = prop.label;
 }
+void SystemTrayMenu::clearMenu()
+{
+//    this->clear();//会崩溃
+}
 
 void SystemTrayMenu::updateMainMenu()
 {
-    this->clear();
-
+    if(!this->isEmpty())
+        this->clear();
     this->addAction(QIcon::fromTheme("help-contents"), gettext("Online &Help!"));
     this->addSeparator();
 
-    bool kbd = this->doUpdateIMListMenu(mIMList);
+    QString currentIM = this->doUpdateIMListMenu(mIMList);
     this->addSeparator();
-
-    if (kbd)
+    if (currentIM=="fcitx-kbd")
     {
         this->doUpdateVKListMenu(mVKList);
         this->addSeparator();
     }
-
-    foreach(const KimpanelProperty &prop, this->mStatusMenuList) {
-           MyAction *menu = new MyAction(QIcon::fromTheme(prop.icon), prop.label, this);
-           menu->setMyActionType(StatusAction);
-           menu->setProp(prop);
-           this->addAction(menu);
+    if (currentIM =="/Fcitx/im/mozc")
+    {
+        this->doUpdateMozcHiraganaListMenu(mMozcHiraganaList);
+        this->doUpdateMozcToolListMenu(mMozcToolList);
+        this->addSeparator();
     }
-    this->addSeparator();
-
+    else
+    {
+        foreach(const KimpanelProperty &prop, this->mStatusMenuList) {
+              MyAction *menu=NULL;
+              if(prop.icon.contains(PREFIX "/share/fcitx"))
+                    menu = new MyAction(QIcon(prop.icon), prop.label, this);
+              else
+                    menu = new MyAction(QIcon::fromTheme(prop.icon), prop.label, this);
+                menu->setMyActionType(StatusAction);
+                menu->setProp(prop);
+                this->addAction(menu);
+        }
+        this->addSeparator();
+}
     this->addAction(QIcon::fromTheme("preferences-desktop"), gettext("ConfigureFcitx"));
     this->addAction(QIcon::fromTheme("preferences-desktop"), gettext("ConfigureIMPanel"));
     this->addSeparator();
@@ -128,9 +165,7 @@ void SystemTrayMenu::updateMainMenu()
         this->addAction(gettext("Text Entry Settings..."));
         this->addSeparator();
     }
-
-    doUpdateSkinListMenu();
-
+        doUpdateSkinListMenu();
 }
 
 void SystemTrayMenu::triggerUpdateVKListMenu()
@@ -143,28 +178,41 @@ void SystemTrayMenu::triggerUpdateIMListMenu()
     mAgent->triggerProperty(QString("/Fcitx/im"));
 }
 
+void SystemTrayMenu::truggerUpdateMozcHiraganaMenu()
+{
+    mAgent->triggerProperty(QString("/Fcitx/mozc-composition-mode"));
+}
+
+void SystemTrayMenu::truggerUpdateMozcToolMenu()
+{
+    mAgent->triggerProperty(QString("/Fcitx/mozc-tool"));
+}
+
 void SystemTrayMenu::doUpdateVKListMenu(const QList<KimpanelProperty> &prop_list)
 {
     MyAction *menu;
     QList<KimpanelProperty>::const_iterator iter;
-
+    mVKListMenu->clear();
     for (iter = prop_list.begin(); iter != prop_list.end(); ++ iter) {
         menu = new MyAction(QIcon::fromTheme(iter->icon), iter->label, this);
-        menu->setMyActionType(VKAction);
         menu->setProp(*iter);
-        this->addAction(menu);
+        mVKListMenu->addAction(menu);
     }
+    this->addMenu(mVKListMenu);
 }
 
-bool SystemTrayMenu::doUpdateIMListMenu(const QList<KimpanelProperty> &prop_list)
+QString SystemTrayMenu::doUpdateIMListMenu(const QList<KimpanelProperty> &prop_list)
 {
     bool checked = false;
+    QString value = "fcitx-kbd";
     MyAction *firstAction = NULL, *action = NULL, *actionChecked = NULL;
     QList<KimpanelProperty>::const_iterator iter;
 
     for (iter = prop_list.begin(); iter != prop_list.end(); ++ iter) {
         if(iter->icon=="fcitx-kbd" || iter->icon==""||iter->icon.indexOf("indicator-keyboard")!=-1)
             action = new MyAction(QIcon::fromTheme("fcitx-kbd"), iter->label, this);
+        else if(iter->icon.contains(PREFIX "/share/fcitx"))
+            action = new MyAction(QIcon(iter->icon), iter->label, this);
         else
             action = new MyAction(QIcon::fromTheme(iter->icon), iter->label, this);
         action->setProp(*iter);
@@ -174,6 +222,10 @@ bool SystemTrayMenu::doUpdateIMListMenu(const QList<KimpanelProperty> &prop_list
             firstAction = action;
         action->setCheckable(true);
         if (iter->label == this->mCurtIMLabel) {
+            if(iter->icon=="fcitx-kbd" || iter->icon==""||iter->icon.indexOf("indicator-keyboard")!=-1)
+                 value = "fcitx-kbd";
+            else
+                 value = iter->key;
             checked = true;
             actionChecked = action;
             action->setChecked(true);
@@ -187,9 +239,33 @@ bool SystemTrayMenu::doUpdateIMListMenu(const QList<KimpanelProperty> &prop_list
     }
 
     if (actionChecked == NULL)
-        return false;
-    else
-        return actionChecked->icon().name() == "fcitx-kbd";
+             value = "fcitx-kbd";
+     return value;
+}
+
+void SystemTrayMenu::doUpdateMozcToolListMenu(const QList<KimpanelProperty> &prop_list)
+{
+    MyAction *menu;
+    QList<KimpanelProperty>::const_iterator iter;
+    mMozcHiraganaMenu->clear();
+    for (iter = prop_list.begin(); iter != prop_list.end(); ++ iter) {
+        menu = new MyAction(QIcon(iter->icon), iter->label, this);
+        menu->setProp(*iter);
+        mMozcHiraganaMenu->addAction(menu);
+    }
+    this->addMenu(mMozcHiraganaMenu);
+}
+void SystemTrayMenu::doUpdateMozcHiraganaListMenu(const QList<KimpanelProperty> &prop_list)
+{
+    MyAction *menu;
+    QList<KimpanelProperty>::const_iterator iter;
+    mMozcToolMenu->clear();
+    for (iter = prop_list.begin(); iter != prop_list.end(); ++ iter) {
+        menu =new MyAction(QIcon(iter->icon), iter->label, this);
+        menu->setProp(*iter);
+        mMozcToolMenu->addAction(menu);
+    }
+    this->addMenu(mMozcToolMenu);
 }
 
 bool SystemTrayMenu::isIMList(const QString &key)
@@ -202,28 +278,44 @@ bool SystemTrayMenu::isVKList(const QString &key)
     return key.startsWith("/Fcitx/vk");
 }
 
+bool SystemTrayMenu::isMozcHiraganaList(const QString &key)
+{
+    return key.startsWith("/Fcitx/mozc-composition-mode");
+}
+
+bool SystemTrayMenu::isMozcToolList(const QString &key)
+{
+    return key.startsWith("/Fcitx/mozc-tool");
+}
+
 void SystemTrayMenu::execMenu(const QList<KimpanelProperty> &prop_list)
 {
+    if(prop_list.isEmpty())
+            return;
     QList<KimpanelProperty>::const_iterator iter = prop_list.begin();
+    if(iter->key.isNull())
+        return;
     if (isIMList(iter->key))
         mIMList = prop_list;
     else if (isVKList(iter->key))
         mVKList = prop_list;
-    else {
+    else if (isMozcHiraganaList(iter->key))
+        mMozcHiraganaList=prop_list;
+    else if (isMozcToolList(iter->key))
+        mMozcToolList = prop_list;
+    else{
         for (iter = prop_list.begin(); iter != prop_list.end(); ++ iter) {
-            qDebug() << QString("execMenuCallback(1:%1 2:%2 3:%3 4:%4 5:%5 6:%6)").arg(iter->key)
-                .arg(iter->label).arg(iter->icon).arg(iter->tip).arg(iter->state).arg(iter->menu);
+//            qDebug() << QString("execMenuCallback(1:%1 2:%2 3:%3 4:%4 5:%5 6:%6)").arg(iter->key)
+//                .arg(iter->label).arg(iter->icon).arg(iter->tip).arg(iter->state).arg(iter->menu);
         }
     }
 
-    updateMainMenu();
 }
 
 void SystemTrayMenu::restart()
 {
     /* exec command */
     pid_t child_pid;
-
     child_pid = fork();
     if (child_pid < 0) {
         perror("fork");
@@ -288,8 +380,9 @@ void SystemTrayMenu::menuItemOnClick(QAction *action)
         if (!toolFile.exists()) {
             QMessageBox::warning(this,gettext("Warning"),gettext("Please install fcitx-qimpanel-configtool!"));
         }
-        startChildApp("fcitx-qimpanel-configtool");
-
+       // getRunCmdOuput("fcitx-qimpanel-configtool");
+        if(configtoolPro->state()!=QProcess::Running)
+                configtoolPro->start("fcitx-qimpanel-configtool");
     } else if (gettext("ConfigureFcitx") == action->text()) {
         mAgent->configure();
 
@@ -330,9 +423,11 @@ void SystemTrayMenu::menuItemOnClick(QAction *action)
         if (SkinAction == myAction->getMyActionType()) {
             skinMenuItemOnClick(myAction);
         } else if (myAction->getProp().key != "") {
+//            qDebug()<<"---------------------"<<myAction->getProp().key;
             mAgent->triggerProperty(myAction->getProp().key);
         }
     }
+//        this->clear();
 }
 
 bool SystemTrayMenu::isUnity()
@@ -353,8 +448,8 @@ void SystemTrayMenu::doUpdateSkinListMenu()
     QString skinName = MainController::self()->getSkinName();
     SkinClass skinClass;
     bool localExist;
-    MyAction *skinNameMenu;
-
+    MyAction *skinNameMenu = NULL;
+    mSkinMenu->clear();
     QString localSkinPath = qgetenv("HOME") + "/.config/fcitx-qimpanel/skin/";
 
     for (i = 0; i < 1; i ++) {
@@ -377,7 +472,7 @@ void SystemTrayMenu::doUpdateSkinListMenu()
                 menu->setMyActionType(SkinAction);
                 menu->setSkinPath(iter->absoluteFilePath() + "/");
                 menu->setSkinClass(skinClass);
-                this->addAction(menu);
+                mSkinMenu->addAction(menu);
                 if (firstMenu == NULL)
                     firstMenu = menu;
                 menu->setCheckable(true);
@@ -428,7 +523,7 @@ void SystemTrayMenu::doUpdateSkinListMenu()
                 //qDebug() << iter->absoluteFilePath();
                 menu->setSkinPath(iter->absoluteFilePath() + "/");
                 menu->setSkinClass(skinClass);
-                this->addAction(menu);
+                mSkinMenu->addAction(menu);
                 if (firstMenu == NULL)
                     firstMenu = menu;
                 menu->setCheckable(true);
@@ -462,7 +557,7 @@ void SystemTrayMenu::doUpdateSkinListMenu()
                 menu->setMyActionType(SkinAction);
                 menu->setSkinPath(iter->absoluteFilePath() + "/");
                 menu->setSkinClass(skinClass);
-                this->addAction(menu);
+                mSkinMenu->addAction(menu);
                 if (firstMenu == NULL)
                     firstMenu = menu;
                 menu->setCheckable(true);
@@ -484,6 +579,7 @@ void SystemTrayMenu::doUpdateSkinListMenu()
     FcitxXDGFreePath(skinPath);
 
     skinMenuItemOnClick(skinNameMenu);
+    this->addMenu(mSkinMenu);
 }
 
 void SystemTrayMenu::skinMenuItemOnClick(QAction* action)
